Release History
===============

master
------

0.2.0 (2018-11-05)
------------------

**Improvements**

* Add MySQL and Celery support. [#8](https://github.com/camelot-dev/excalibur/pull/8) by Vinayak Mehta.
* Add table auto-detection. [#7](https://github.com/camelot-dev/excalibur/pull/7) by Vinayak Mehta.
* Add static website. [#6](https://github.com/camelot-dev/excalibur/pull/6) by Nikhil Sikka.

0.1.1 (2018-10-22)
------------------

* Add Windows and Linux executables.

0.1.0 (2018-10-20)
------------------

* Birth!
